/*
 * FISG - Output Modules Header
 * Programmed and designed by Matti 'ccr' Hamalainen
 * (C) Copyright 2003 Tecnic Software productions (TNSP)
 *
 * Please read file 'COPYING' for information on license and distribution.
 */
#include "out_formats.h"

/*
 * Functions
 */
int output_xhtml(FILE *, t_stats *, t_config *);
int output_xhtmls(FILE *, t_stats *, t_config *);



/*
 * List of output formats
 */
const t_outformat	outputFormats[] = {
	{ "xhtml",	"XHTML/CSS output",	output_xhtml },
	{ "xhtmls",	"XHTML/CSS output with table borders",	output_xhtmls }
};


const int	nOutputFormats = (sizeof(outputFormats) / sizeof(t_outformat));

